'''
Author:      www.tropofy.com

Copyright 2013 Tropofy Pty Ltd, all rights reserved.

This source file is part of Tropofy and govered by the Tropofy terms of service
available at: http://www.tropofy.com/terms_of_service.html

This source file is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
'''


class LoadedApps(object):
    apps = {}


from data_set import AppDataSet, DataSetVar, SavedImageReference, CeleryTask, SynchronousTask, TaskResultMeta
from application import App, AppWithDataSets, Parameter, Step, StepGroup
from app_manager import AppManager
